@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Schema::Perl;
 
-our $VERSION = '0.016_003'; # TRIAL VERSION
+our $VERSION = '0.018_001'; # TRIAL VERSION
 
 use Scalar::Util qw/ blessed reftype /;
 
@@ -506,7 +506,7 @@ You can define the style of tags you want to support:
 
 =over
 
-=item C<!perl>
+=item C<!perl> (default)
 
 Only C<!perl/type> tags are supported.
 
@@ -715,7 +715,6 @@ YAML:
 
         # Code
         my $string = 'unblessed';
-        utf8::upgrade($string);
         qr{$string}
 
 
@@ -727,7 +726,6 @@ YAML:
 
         # Code
         my $string = 'blessed';
-        utf8::upgrade($string);
         bless qr{$string}, "Foo"
 
 
@@ -778,7 +776,6 @@ YAML:
     my $perl = YAML::PP::Schema::Perl->new(
         tags => "!perl",
         classes => ['MyClass'],
-        objects => 1,
         loadcode => 1,
     );
 
